==> docs_sdk_archive_luna-sdk_alma_rel_v.5.31.2.zip: docs_sdk_archive_luna-sdk_alma_rel_v.5.31.2/luna-sdk_alma_rel_v.5.31.2/doc/fsdk/html/search/all_5.js <==
var searchData=
[
  ['face',['Face',['../structfsdk_1_1_face.html',1,'fsdk']]],
  ['face_5fdet_5fcount',['FACE_DET_COUNT',['../group___detector_group.html#ggab83a85f36a0025dac2b8b6d41b88bd8ca53e96ce2b5c1880ce5588a4b099eb24b',1,'fsdk']]],
  ['face_5fdet_5fdefault',['FACE_DET_DEFAULT',['../group___detector_group.html#ggab83a85f36a0025dac2b8b6d41b88bd8ca908b2d58b338d34863dc56d21474ffc3',1,'fsdk']]],
  ['face_5fdet_5fv2',['FACE_DET_V2',['../group___detector_group.html#ggab83a85f36a0025dac2b8b6d41b88bd8caed0da3a5db3f97c5eb927a1696de2d65',1,'fsdk']]],
  ['face_5fdet_5fv3',['FACE_DET_V3',['../group___detector_group.html#ggab83a85f36a0025dac2b8b6d41b88bd8cafd6028fd9b68847f58ab7a089cedd57d',1,'fsdk']]],
  ['face_5fdet_5fv3m',['FACE_DET_V3M',['../group___detector_group.html#ggab83a85f36a0025dac2b8b6d41b88bd8cadc47ab19e9ab3a984a129be5b1d1febc',1,'fsdk']]],
  ['facebatchfuture',['FaceBatchFuture',['../structfsdk_1_1_i_detector.html#adbb9c77a4c0ca459733b84b74a658ffe',1,'fsdk::IDetector']]],
  ['faceengine_2eh',['FaceEngine.h',['../_face_engine_8h.html',1,'']]],
  ['facelandmarksbatchfuture',['FaceLandmarksBatchFuture',['../structfsdk_1_1_i_face_landmarks_detector.html#a63ed98e6dd7b978380765d870496ed68',1,'fsdk::IFaceLandmarksDetector']]],
  ['faceocclusionestimation',['FaceOcclusionEstimation',['../structfsdk_1_1_face_occlusion_estimation.html',1,'fsdk']]],
  ['faceocclusionstate',['FaceOcclusionState',['../group___occlusion_estimator_group.html#ga843192d016e3a14dc5c9a3ef75d5124f',1,'fsdk']]],
  ['faceocclusiontype',['FaceOcclusionType',['../group___occlusion_estimator_group.html#ga8b3ddce447c4f06eb4413fc267796a26',1,'fsdk']]],
  ['facialhair',['FacialHair',['../group___estimator_group.html#gac40caf1f72fab400cd2460f9ac2237c0',1,'fsdk']]],
  ['facialhairestimation',['FacialHairEstimation',['../structfsdk_1_1_facial_hair_estimation.html',1,'fsdk']]],
  ['fail',['fail',['../classfsdk_1_1_promise.html#a0c73e4d84c3e6487d5a7e1f7b0c13ba0',1,'fsdk::Promise']]],
  ['failed',['Failed',['../namespacefsdk.html#a48fe9106b62424a924a260074cd2c82bad7c8c85bf79bbe1b7188497c32c3b0ca',1,'fsdk']]],
  ['failedtoinitialize',['FailedToInitialize',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936ade906b82a6f70f5f75ea0a11da932a36',1,'fsdk::Image']]],
  ['failedtoload',['FailedToLoad',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936a023fe093cb8dbc5a80d2a2259d4c97a5',1,'fsdk::Image']]],
  ['failedtosave',['FailedToSave',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936a70fa83b68f2d20d1c607a2864627f13d',1,'fsdk::Image']]],
  ['fake',['Fake',['../group___estimator_group.html#gga94d3646e61ffe5c0c99ea0318e359bd7a52a96508c39536f0c2ef43b19a0a1e0e',1,'fsdk::experimental::DeepFakeEstimation::Fake()'],['../structfsdk_1_1_liveness_one_shot_r_g_b_estimation.html#a0a15d2c39c2975369d9ad85b53392f56a52a96508c39536f0c2ef43b19a0a1e0e',1,'fsdk::LivenessOneShotRGBEstimation::Fake()'],['../structfsdk_1_1_n_i_r_liveness_estimation.html#ab465ad1dcb3273ced350445ad51aa02aa52a96508c39536f0c2ef43b19a0a1e0e',1,'fsdk::NIRLivenessEstimation::Fake()']]],
  ['fear',['fear',['../structfsdk_1_1_emotions_estimation.html#a80fa765273d4c2b4f60d09a5879b012b',1,'fsdk::EmotionsEstimation']]],
  ['featureexpired',['FeatureExpired',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a84decd8ce021a70aef62a2283ea8d559',1,'fsdk']]],
  ['featurenotavailable',['FeatureNotAvailable',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6afb12ff30441dbc154f6d2591169f012c',1,'fsdk']]],
  ['female',['female',['../structfsdk_1_1_human_attribute_result_1_1_gender_estimation.html#a1d6dfb36078a28225d34ae6b7bcf530e',1,'fsdk::HumanAttributeResult::GenderEstimation::female()'],['../structfsdk_1_1_human_attribute_result.html#a34ec582956ee03ce763a98687417973fab719ce180ec7bd9641fece2f920f4817',1,'fsdk::HumanAttributeResult::Female()']]],
  ['fight',['Fight',['../structfsdk_1_1_fights_estimation.html#aea94b3828eb9c964a7fd0b07f4f1fe05ac8b01a3184580b42a0bfbc05d2dab784',1,'fsdk::FightsEstimation']]],
  ['fightsestimation',['FightsEstimation',['../structfsdk_1_1_fights_estimation.html',1,'fsdk']]],
  ['filenotfound',['FileNotFound',['../structfsdk_1_1_i_settings_provider.html#a645a0b8fb7db4e4d2ddc5bdb68a5cad5a2767828026039e8ba7b38973cbb701f2',1,'fsdk::ISettingsProvider']]],
  ['filtredaggregationerror',['FiltredAggregationError',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a3e095f1fa338dccd7cc239c47593fd7a',1,'fsdk']]],
  ['fingerprint',['Fingerprint',['../structfsdk_1_1_fingerprint.html',1,'fsdk']]],
  ['fingerprinterror',['FingerprintError',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a455a3a357ebc7221085d184c157c13a5',1,'fsdk']]],
  ['fingerprintinternalmismatch',['FingerprintInternalMismatch',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a1d2f1a175813148aa3be0d8c868e1c53',1,'fsdk']]],
  ['fisheye',['FishEye',['../group___estimator_group.html#ga364aa8a6ba6e9e6ca82390a6064d23c6',1,'fsdk']]],
  ['fisheyeeffect',['FishEyeEffect',['../group___estimator_group.html#gga364aa8a6ba6e9e6ca82390a6064d23c6a9ec948a9dbe4ad763f933b587c7156a6',1,'fsdk']]],
  ['fisheyeestimation',['FishEyeEstimation',['../structfsdk_1_1_fish_eye_estimation.html',1,'fsdk']]],
  ['flags',['Flags',['../structfsdk_1_1_i_serializable_object.html#ac02b734576139d792a928b0a9ade7d79',1,'fsdk::ISerializableObject']]],
  ['float1',['Float1',['../structfsdk_1_1_i_settings_provider_1_1_value_1_1_data_1_1_float1.html',1,'fsdk::ISettingsProvider::Value::Data::Float1'],['../structfsdk_1_1_i_settings_provider_1_1_value.html#a593ad9694be5ec4dfe8982cef26fe947afce0cbbaf3da4fd239865223a2cafd2d',1,'fsdk::ISettingsProvider::Value::Float1()']]],
  ['float2',['Float2',['../structfsdk_1_1_i_settings_provider_1_1_value_1_1_data_1_1_float2.html',1,'fsdk::ISettingsProvider::Value::Data::Float2'],['../structfsdk_1_1_i_settings_provider_1_1_value.html#a593ad9694be5ec4dfe8982cef26fe947acab9b95fc0f8e22586956c7b2831c742',1,'fsdk::ISettingsProvider::Value::Float2()']]],
  ['float3',['Float3',['../structfsdk_1_1_i_settings_provider_1_1_value_1_1_data_1_1_float3.html',1,'fsdk::ISettingsProvider::Value::Data::Float3'],['../structfsdk_1_1_i_settings_provider_1_1_value.html#a593ad9694be5ec4dfe8982cef26fe947ac1e9d375777e2ca4631b5e4851a8e70c',1,'fsdk::ISettingsProvider::Value::Float3()']]],
  ['float4',['Float4',['../structfsdk_1_1_i_settings_provider_1_1_value_1_1_data_1_1_float4.html',1,'fsdk::ISettingsProvider::Value::Data::Float4'],['../structfsdk_1_1_i_settings_provider_1_1_value.html#a593ad9694be5ec4dfe8982cef26fe947a96cf9d7a2ede9c47b110b3a4178f3401',1,'fsdk::ISettingsProvider::Value::Float4()']]],
  ['flyingfacesscore',['flyingFacesScore',['../structfsdk_1_1_liveness_f_p_r_estimation.html#a04c339888175790f41beaccf745fb86b',1,'fsdk::LivenessFPREstimation']]],
  ['forehead',['Forehead',['../group___occlusion_estimator_group.html#gga8b3ddce447c4f06eb4413fc267796a26a1ca0cb4d1f0b41b4fb726abb7c0af2de',1,'fsdk']]],
  ['format',['Format',['../structfsdk_1_1_format.html',1,'fsdk::Format'],['../structfsdk_1_1_format.html#aa45f2da762d2fce103d97aa803078d84',1,'fsdk::Format::Format() noexcept'],['../structfsdk_1_1_format.html#a9fae615ad7c67630f9546abd6d568175',1,'fsdk::Format::Format(Type type) noexcept'],['../structfsdk_1_1_sub_image.html#abe52716506d7e423d133507007d52a89',1,'fsdk::SubImage::format()']]],
  ['fromstring',['fromString',['../structfsdk_1_1_format.html#a0243dc15ba02ac5e0b8727ae4e19c4f5',1,'fsdk::Format']]],
  ['frontalfacetype',['FrontalFaceType',['../structfsdk_1_1_head_pose_estimation.html#aa2121a6759ada82ee49750f4922fd9a7',1,'fsdk::HeadPoseEstimation']]],
  ['frowningscore',['frowningScore',['../structfsdk_1_1_eye_brow_estimation.html#af878ffdbcef72c65c53c51a3d6dff2e7',1,'fsdk::EyeBrowEstimation']]],
  ['fsdk',['fsdk',['../namespacefsdk.html',1,'']]],
  ['fsdk_5fapi',['FSDK_API',['../_def_8h.html#a5dc4c3043f171426dafe6fc800218945',1,'Def.h']]],
  ['fsdk_5fdeprecated',['FSDK_DEPRECATED',['../structfsdk_1_1_i_license.html#abb9a39db898ba468d40c4d04d5e8b9cb',1,'fsdk::ILicense']]],
  ['fsdkerror',['FSDKError',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6',1,'fsdk']]],
  ['fsdkerror_2eh',['FSDKError.h',['../_f_s_d_k_error_8h.html',1,'']]],
  ['fulfill',['fulfill',['../classfsdk_1_1_promise.html#a379829f59f04b7694423b3e82d501766',1,'fsdk::Promise']]],
  ['fulfilled',['Fulfilled',['../namespacefsdk.html#a48fe9106b62424a924a260074cd2c82ba2a6de846fd07e369786e3f5b41e20455',1,'fsdk']]],
  ['fullmask',['FullMask',['../group___estimator_group.html#gga12b3d18d0723cdafd86b4902241f5cb0a32950741c2a4db230a8af70867adc378',1,'fsdk']]],
  ['functiondetectioncomparer',['FunctionDetectionComparer',['../classfsdk_1_1_function_detection_comparer.html',1,'fsdk']]],
  ['future',['Future',['../classfsdk_1_1_future.html',1,'fsdk::Future&lt; T &gt;'],['../classfsdk_1_1_future.html#a88569ef592c8f9793067cb1139123aaf',1,'fsdk::Future::Future()'],['../classfsdk_1_1_promise.html#accb944e8905435482b8604dfb805d690',1,'fsdk::Promise::future()']]],
  ['futureerror',['FutureError',['../namespacefsdk.html#ab7f8be96a87fd4e85bd762a7f8f8f8fb',1,'fsdk']]],
  ['futurepromisestate',['FuturePromiseState',['../namespacefsdk.html#a48fe9106b62424a924a260074cd2c82b',1,'fsdk']]],
  ['futureresult',['FutureResult',['../structfsdk_1_1_i_descriptor_extractor.html#a99a4f2d66cd4fc28a69cd02b9348817c',1,'fsdk::IDescriptorExtractor']]]
];

==> docs_sdk_archive_luna-sdk_alma_rel_v.5.32.0.zip: docs_sdk_archive_luna-sdk_alma_rel_v.5.32.0/luna-sdk_alma_rel_v.5.32.0/doc/fsdk/html/search/all_5.js <==
var searchData=
[
  ['face',['Face',['../structfsdk_1_1_face.html',1,'fsdk']]],
  ['face_5fdet_5fcount',['FACE_DET_COUNT',['../group___detector_group.html#ggab83a85f36a0025dac2b8b6d41b88bd8ca53e96ce2b5c1880ce5588a4b099eb24b',1,'fsdk']]],
  ['face_5fdet_5fdefault',['FACE_DET_DEFAULT',['../group___detector_group.html#ggab83a85f36a0025dac2b8b6d41b88bd8ca908b2d58b338d34863dc56d21474ffc3',1,'fsdk']]],
  ['face_5fdet_5fv2',['FACE_DET_V2',['../group___detector_group.html#ggab83a85f36a0025dac2b8b6d41b88bd8caed0da3a5db3f97c5eb927a1696de2d65',1,'fsdk']]],
  ['face_5fdet_5fv3',['FACE_DET_V3',['../group___detector_group.html#ggab83a85f36a0025dac2b8b6d41b88bd8cafd6028fd9b68847f58ab7a089cedd57d',1,'fsdk']]],
  ['face_5fdet_5fv3m',['FACE_DET_V3M',['../group___detector_group.html#ggab83a85f36a0025dac2b8b6d41b88bd8cadc47ab19e9ab3a984a129be5b1d1febc',1,'fsdk']]],
  ['facebatchfuture',['FaceBatchFuture',['../structfsdk_1_1_i_detector.html#adbb9c77a4c0ca459733b84b74a658ffe',1,'fsdk::IDetector']]],
  ['faceengine_2eh',['FaceEngine.h',['../_face_engine_8h.html',1,'']]],
  ['facelandmarksbatchfuture',['FaceLandmarksBatchFuture',['../structfsdk_1_1_i_face_landmarks_detector.html#a63ed98e6dd7b978380765d870496ed68',1,'fsdk::IFaceLandmarksDetector']]],
  ['faceocclusionestimation',['FaceOcclusionEstimation',['../structfsdk_1_1_face_occlusion_estimation.html',1,'fsdk']]],
  ['faceocclusionstate',['FaceOcclusionState',['../group___occlusion_estimator_group.html#ga843192d016e3a14dc5c9a3ef75d5124f',1,'fsdk']]],
  ['faceocclusiontype',['FaceOcclusionType',['../group___occlusion_estimator_group.html#ga8b3ddce447c4f06eb4413fc267796a26',1,'fsdk']]],
  ['facialhair',['FacialHair',['../group___estimator_group.html#gac40caf1f72fab400cd2460f9ac2237c0',1,'fsdk']]],
  ['facialhairestimation',['FacialHairEstimation',['../structfsdk_1_1_facial_hair_estimation.html',1,'fsdk']]],
  ['fail',['fail',['../classfsdk_1_1_promise.html#a0c73e4d84c3e6487d5a7e1f7b0c13ba0',1,'fsdk::Promise']]],
  ['failed',['Failed',['../namespacefsdk.html#a48fe9106b62424a924a260074cd2c82bad7c8c85bf79bbe1b7188497c32c3b0ca',1,'fsdk']]],
  ['failedtoinitialize',['FailedToInitialize',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936ade906b82a6f70f5f75ea0a11da932a36',1,'fsdk::Image']]],
  ['failedtoload',['FailedToLoad',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936a023fe093cb8dbc5a80d2a2259d4c97a5',1,'fsdk::Image']]],
  ['failedtosave',['FailedToSave',['../structfsdk_1_1_image.html#a7929a4eb6155bd9430dac56142672936a70fa83b68f2d20d1c607a2864627f13d',1,'fsdk::Image']]],
  ['fake',['Fake',['../group___estimator_group.html#gga94d3646e61ffe5c0c99ea0318e359bd7a52a96508c39536f0c2ef43b19a0a1e0e',1,'fsdk::experimental::DeepFakeEstimation::Fake()'],['../structfsdk_1_1_liveness_one_shot_r_g_b_estimation.html#a0a15d2c39c2975369d9ad85b53392f56a52a96508c39536f0c2ef43b19a0a1e0e',1,'fsdk::LivenessOneShotRGBEstimation::Fake()'],['../structfsdk_1_1_n_i_r_liveness_estimation.html#ab465ad1dcb3273ced350445ad51aa02aa52a96508c39536f0c2ef43b19a0a1e0e',1,'fsdk::NIRLivenessEstimation::Fake()']]],
  ['fear',['fear',['../structfsdk_1_1_emotions_estimation.html#a80fa765273d4c2b4f60d09a5879b012b',1,'fsdk::EmotionsEstimation']]],
  ['featureexpired',['FeatureExpired',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a84decd8ce021a70aef62a2283ea8d559',1,'fsdk']]],
  ['featurenotavailable',['FeatureNotAvailable',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6afb12ff30441dbc154f6d2591169f012c',1,'fsdk']]],
  ['female',['female',['../structfsdk_1_1_human_attribute_result_1_1_gender_estimation.html#a1d6dfb36078a28225d34ae6b7bcf530e',1,'fsdk::HumanAttributeResult::GenderEstimation::female()'],['../structfsdk_1_1_human_attribute_result.html#a34ec582956ee03ce763a98687417973fab719ce180ec7bd9641fece2f920f4817',1,'fsdk::HumanAttributeResult::Female()']]],
  ['fight',['Fight',['../structfsdk_1_1_fights_estimation.html#aea94b3828eb9c964a7fd0b07f4f1fe05ac8b01a3184580b42a0bfbc05d2dab784',1,'fsdk::FightsEstimation']]],
  ['fightsestimation',['FightsEstimation',['../structfsdk_1_1_fights_estimation.html',1,'fsdk']]],
  ['filenotfound',['FileNotFound',['../structfsdk_1_1_i_settings_provider.html#a645a0b8fb7db4e4d2ddc5bdb68a5cad5a2767828026039e8ba7b38973cbb701f2',1,'fsdk::ISettingsProvider']]],
  ['filtredaggregationerror',['FiltredAggregationError',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a3e095f1fa338dccd7cc239c47593fd7a',1,'fsdk']]],
  ['fingerprint',['Fingerprint',['../structfsdk_1_1_fingerprint.html',1,'fsdk']]],
  ['fingerprinterror',['FingerprintError',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a455a3a357ebc7221085d184c157c13a5',1,'fsdk']]],
  ['fingerprintinternalmismatch',['FingerprintInternalMismatch',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a1d2f1a175813148aa3be0d8c868e1c53',1,'fsdk']]],
  ['fisheye',['FishEye',['../group___estimator_group.html#ga364aa8a6ba6e9e6ca82390a6064d23c6',1,'fsdk']]],
  ['fisheyeeffect',['FishEyeEffect',['../group___estimator_group.html#gga364aa8a6ba6e9e6ca82390a6064d23c6a9ec948a9dbe4ad763f933b587c7156a6',1,'fsdk']]],
  ['fisheyeestimation',['FishEyeEstimation',['../structfsdk_1_1_fish_eye_estimation.html',1,'fsdk']]],
  ['flags',['Flags',['../structfsdk_1_1_i_serializable_object.html#ac02b734576139d792a928b0a9ade7d79',1,'fsdk::ISerializableObject']]],
  ['float1',['Float1',['../structfsdk_1_1_i_settings_provider_1_1_value_1_1_data_1_1_float1.html',1,'fsdk::ISettingsProvider::Value::Data::Float1'],['../structfsdk_1_1_i_settings_provider_1_1_value.html#a593ad9694be5ec4dfe8982cef26fe947afce0cbbaf3da4fd239865223a2cafd2d',1,'fsdk::ISettingsProvider::Value::Float1()']]],
  ['float2',['Float2',['../structfsdk_1_1_i_settings_provider_1_1_value_1_1_data_1_1_float2.html',1,'fsdk::ISettingsProvider::Value::Data::Float2'],['../structfsdk_1_1_i_settings_provider_1_1_value.html#a593ad9694be5ec4dfe8982cef26fe947acab9b95fc0f8e22586956c7b2831c742',1,'fsdk::ISettingsProvider::Value::Float2()']]],
  ['float3',['Float3',['../structfsdk_1_1_i_settings_provider_1_1_value_1_1_data_1_1_float3.html',1,'fsdk::ISettingsProvider::Value::Data::Float3'],['../structfsdk_1_1_i_settings_provider_1_1_value.html#a593ad9694be5ec4dfe8982cef26fe947ac1e9d375777e2ca4631b5e4851a8e70c',1,'fsdk::ISettingsProvider::Value::Float3()']]],
  ['float4',['Float4',['../structfsdk_1_1_i_settings_provider_1_1_value_1_1_data_1_1_float4.html',1,'fsdk::ISettingsProvider::Value::Data::Float4'],['../structfsdk_1_1_i_settings_provider_1_1_value.html#a593ad9694be5ec4dfe8982cef26fe947a96cf9d7a2ede9c47b110b3a4178f3401',1,'fsdk::ISettingsProvider::Value::Float4()']]],
  ['forehead',['Forehead',['../group___occlusion_estimator_group.html#gga8b3ddce447c4f06eb4413fc267796a26a1ca0cb4d1f0b41b4fb726abb7c0af2de',1,'fsdk']]],
  ['format',['Format',['../structfsdk_1_1_format.html',1,'fsdk::Format'],['../structfsdk_1_1_format.html#aa45f2da762d2fce103d97aa803078d84',1,'fsdk::Format::Format() noexcept'],['../structfsdk_1_1_format.html#a9fae615ad7c67630f9546abd6d568175',1,'fsdk::Format::Format(Type type) noexcept'],['../structfsdk_1_1_sub_image.html#abe52716506d7e423d133507007d52a89',1,'fsdk::SubImage::format()']]],
  ['fromstring',['fromString',['../structfsdk_1_1_format.html#a0243dc15ba02ac5e0b8727ae4e19c4f5',1,'fsdk::Format']]],
  ['frontalfacetype',['FrontalFaceType',['../structfsdk_1_1_head_pose_estimation.html#aa2121a6759ada82ee49750f4922fd9a7',1,'fsdk::HeadPoseEstimation']]],
  ['frowningscore',['frowningScore',['../structfsdk_1_1_eye_brow_estimation.html#af878ffdbcef72c65c53c51a3d6dff2e7',1,'fsdk::EyeBrowEstimation']]],
  ['fsdk',['fsdk',['../namespacefsdk.html',1,'']]],
  ['fsdk_5fapi',['FSDK_API',['../_def_8h.html#a5dc4c3043f171426dafe6fc800218945',1,'Def.h']]],
  ['fsdk_5fdeprecated',['FSDK_DEPRECATED',['../structfsdk_1_1_i_face_engine.html#a76b2da4f1fd8c27d7b950f8564623513',1,'fsdk::IFaceEngine::FSDK_DEPRECATED()'],['../group___core_group.html#ga5bd00c809dbfce9689147053f56ad9d2',1,'fsdk::IFaceEnginePos::FSDK_DEPRECATED()']]],
  ['fsdkerror',['FSDKError',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6',1,'fsdk']]],
  ['fsdkerror_2eh',['FSDKError.h',['../_f_s_d_k_error_8h.html',1,'']]],
  ['fulfill',['fulfill',['../classfsdk_1_1_promise.html#a379829f59f04b7694423b3e82d501766',1,'fsdk::Promise']]],
  ['fulfilled',['Fulfilled',['../namespacefsdk.html#a48fe9106b62424a924a260074cd2c82ba2a6de846fd07e369786e3f5b41e20455',1,'fsdk']]],
  ['fullmask',['FullMask',['../group___estimator_group.html#gga12b3d18d0723cdafd86b4902241f5cb0a32950741c2a4db230a8af70867adc378',1,'fsdk']]],
  ['functiondetectioncomparer',['FunctionDetectionComparer',['../classfsdk_1_1_function_detection_comparer.html',1,'fsdk']]],
  ['future',['Future',['../classfsdk_1_1_future.html',1,'fsdk::Future&lt; T &gt;'],['../classfsdk_1_1_future.html#a88569ef592c8f9793067cb1139123aaf',1,'fsdk::Future::Future()'],['../classfsdk_1_1_promise.html#accb944e8905435482b8604dfb805d690',1,'fsdk::Promise::future()']]],
  ['futureerror',['FutureError',['../namespacefsdk.html#ab7f8be96a87fd4e85bd762a7f8f8f8fb',1,'fsdk']]],
  ['futurepromisestate',['FuturePromiseState',['../namespacefsdk.html#a48fe9106b62424a924a260074cd2c82b',1,'fsdk']]],
  ['futureresult',['FutureResult',['../structfsdk_1_1_i_descriptor_extractor.html#a99a4f2d66cd4fc28a69cd02b9348817c',1,'fsdk::IDescriptorExtractor']]]
];
